printenviron

package
v0.0.0-...-c8c5826 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2024 License: GPL-3.0 Imports: 2 Imported by: 0

README

print-environ

A simple utility for printing the key:value pairs on newlines representing the current environment variables.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Main

func Main()

prints the current environment variables on newlines with entries in the format of 'key=val'

Types

This section is empty.

Jump to